function [times, values] = gravity_ode(speed, angle, height) 
% gravity_ode: The trajectory of a ball thrown from (0,0) with initial 
%               speed and angle (in degrees) given. 
%    times: (1) = time ball at peak, (2) = time ball hits ground 
%           (3,4) = time ball attains height 
%    values: (1) = z value at peak, (2) = x value when ball hits ground 
%            (3,4) = x values when ball attains height 
%    Note: (3,4) will not be used if height > z value at peak 
g = 9.8; 
gravity_init() 
[t, Y, tevent, Yevent, index_event] =   ode45(@gravity, tspan, y0, params); 
if length(tevent) == 2 
   times = tevent; 
   values = [Yevent(1,3) Yevent(2,1)]; 
else 
   times = tevent([2 4 1 3]); 
   values = [Yevent(2,3) Yevent(4,1) Yevent(1,1) Yevent(3,1)]; 
end 
   %%%%% nested functions follow 
   function gravity_init 
   % gravity_init: Initialize everything 
   tspan = [0 10*speed/g]; 
   y0 = [ 0; speed*cos(angle*pi/180); 0; speed*sin(angle*pi/180) ]; 
   params = odeset('RelTol', 1.e-6, ... 
                   'Events', @gravity_event, ... 
                   'Refine', 20, ... 
                   'OutputFcn', 'odephas2', ... 
                   'OutputSel', [1 3]); 
   end 
   function deriv = gravity(t, y) 
   % gravity: Calculates the right-hand side of the ode 
   deriv = [y(2); 0; y(4); -g]; 
   end 
   function [value, isterminal, direction] = gravity_event(t, y) 
   % gravity_event: determines the events \
   value = [y(3); y(3)-height; y(4)];      % z = 0, z-height = 0, z' = 0 
   isterminal = [1; 0; 0];      % halt only when z = 0 
   direction = [-1; 0; -1];      % an event occurs when z or z' decrease through 0 
                               % or z-height passes through 0 in either direction 
   end 
end